@@ -1,5 +1,5 @@
 
-class Mesures():
+class MesureBase():
     def __init__(self, T_th = None):
         self.T_th = T_th
         self.Vmin = None
@@ -10,4 +10,5 @@ class Mesures():
         self.Vpp = None
         self.Vdc = None
         self.Veff = None
-
+        self.trigger_bas = None
+        self.trigger_haut = None
