@@ -14,12 +14,12 @@ except:
 from signaux.signal_1_base import Signal1Base
 from signaux.signalll import Signal
 
-import base.temps_base
+import base.axe_x_base
 import base.voie_base
 import base.utiles_base as utb
 
 from sysam.sysam_4_methodes import Sysam4Methodes
-
+from plot.plot_base import tracer
 __all__ = ["demarrer_sysam", "acquerir_signaux"]
 
 def acquerir_signaux(*args, **kwargs):
@@ -74,14 +74,14 @@ class SysamSP5(Sysam4Methodes):
             self.sysam.acquerir_avec_sorties(*self.calculer_arguments_acquerir_avec_sorties())
             self.mettre_a_jour_entrees()
         elif "entree" in self.chaine_mode and "sortie" in self.chaine_mode:
-            tmin, tmax = self.base_de_temps_entrees.calculer_liste_tmin_tmax()
+            xmin, xmax = self.axe_x_base_entrees.calculer_liste_xmin_xmax()
             self.sysam.declencher_sorties(*self.calculer_arguments_declencher_sorties())
-            if tmin != 0:
-                time.sleep(tmin)
+            if xmin != 0:
+                time.sleep(xmin)
             self.sysam.acquerir()
             self.mettre_a_jour_entrees()
         elif "entree" in self.chaine_mode and "sortie" not in self.chaine_mode:
-            tmin, tmax = self.base_de_temps_entrees.calculer_liste_tmin_tmax()
+            xmin, xmax = self.axe_x_base_entrees.calculer_liste_xmin_xmax()
             self.sysam.acquerir()
             self.mettre_a_jour_entrees()            
         elif "sortie" in self.chaine_mode and "entree" not in self.chaine_mode:
@@ -93,40 +93,32 @@ class SysamSP5(Sysam4Methodes):
                     test_fin = True
 
     def mettre_a_jour_entrees(self):
-        print("On met les entrées à jour")
+        # print("On met les entrées à jour")
         temps = self.sysam.temps()
         entrees = self.sysam.entrees()
         voies = self.calculer_arguments_config_entrees()[0]
         # print("mettre a jour entrees ", self.chaine_mode)
         if "synchrone" not in self.chaine_mode:
-            Nsysam = np.max(base.temps_base.TempsBase.liste_bases_de_temps_sysam) + 1
-            base.temps_base.TempsBase.liste_bases_de_temps_sysam.append(Nsysam)
+            Nsysam = np.max(base.axe_x_base.AxeXBase.liste_NBase) + 1
+            base.axe_x_base.AxeXBase.liste_NBase.append(Nsysam)
         else:
             Nsysam = 0
 
         for s in self.liste_entrees:
-            voie = s.lire_voie_base().calculer_numero()
+            voie = s._Signal6Sysam__lire_voie_base().calculer_numero()
             indice = voies.index(voie)
-            s._Signal1Base__vecteur_signal = np.array(entrees[indice])
-            s._Signal1Base__base_de_temps = base.temps_base.calculer_base_de_temps(np.array(temps[indice]))
-            s._Signal1Base__base_de_temps.Nsysam = Nsysam
+            s._Signal1Base__vecteur_y = np.array(entrees[indice])
+            s._PlotBase__axe_x_base = base.axe_x_base.calculer_axe_x_base(np.array(temps[indice]))
+            s._PlotBase__axe_x_base.Nsysam = Nsysam
 
 if __name__ == "__main__":
     liste_tmin_tmax = [0, 1e-4]
-    Te = 1e-5
+    Te = 1e-6
     s1 = Signal(liste_tmin_tmax =liste_tmin_tmax, nom_voie = "EA0", Te = Te, seuil = 0, pretrigger = 3)
-    s2 = Signal(liste_tmin_tmax =liste_tmin_tmax, nom_voie = "DIFF2", Te = Te)
-    s3 = Signal(liste_tmin_tmax =liste_tmin_tmax, nom_voie = "EA3", Te = Te)
-    s4 = Signal(liste_tmin_tmax =liste_tmin_tmax, nom_voie = "SA1", Te = Te)
-    s5 = Signal(liste_tmin_tmax =liste_tmin_tmax, nom_voie = "SA2", Te = Te)
+    # s2 = Signal(liste_tmin_tmax =liste_tmin_tmax, nom_voie = "DIFF2", Te = Te)
+    # s3 = Signal(liste_tmin_tmax =liste_tmin_tmax, nom_voie = "EA3", Te = Te)
+    # s4 = Signal(liste_tmin_tmax =liste_tmin_tmax, nom_voie = "SA2", Te = Te)
+    s5 = Signal(F = 1e4, liste_tmin_tmax =liste_tmin_tmax, nom_voie = "SA1", Te = Te)
     
-    demarrer_sysam(s1, s2, s3, s4, s5, True)
-    s1.plot()
-    s2.plot()
-    s3.plot()
-    s4.plot()
-    s5.plot()
-    plt.legend()
-    plt.show()
-    print(type(s1))
-    # SignalGBF.tracer_signaux(sortie2, entree1, entree2, titre = "zoo")
\ No newline at end of file
+    demarrer_sysam(s1, s5, True)
+    tracer(s1, s5, superposition = False)
\ No newline at end of file
